pub enum MountedFileSizePolicy {
PreviousOrZero,
PreviousOrMemoryPages,
Explicit(u64),
MemoryPages,
}Expand description
Mounting policy to determine actual mounted memory file size
Variants
PreviousOrZero
Reuse the size from a previous mount or 0 if unknown
PreviousOrMemoryPages
Reuse the size from a previous mount or determine from memory pages.
Explicit(u64)
Explicitly set the file size, overriding other options.
MemoryPages
Determine file size from the memory pages.
Implementations